<a id="packages.valory.connections.abci.tests.test_fuzz.base"></a>

# packages.valory.connections.abci.tests.test`_`fuzz.base

Defines the base of the fuzzy tests

<a id="packages.valory.connections.abci.tests.test_fuzz.base.BaseFuzzyTests"></a>

## BaseFuzzyTests Objects

```python
class BaseFuzzyTests(AEATestCaseMany)
```

Base class for the Fuzzy Tests

<a id="packages.valory.connections.abci.tests.test_fuzz.base.BaseFuzzyTests.setup_class"></a>

#### setup`_`class

```python
@classmethod
def setup_class(cls) -> None
```

Sets up the environment for the tests.

<a id="packages.valory.connections.abci.tests.test_fuzz.base.BaseFuzzyTests.teardown_class"></a>

#### teardown`_`class

```python
@classmethod
def teardown_class(cls) -> None
```

Tear down the testing environment.

